aboutsummaryrefslogtreecommitdiff
path: root/gdb/source.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/source.c')
-rw-r--r--gdb/source.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/source.c b/gdb/source.c
index 3410e86..69480ef 100644
--- a/gdb/source.c
+++ b/gdb/source.c
@@ -758,7 +758,7 @@ prepare_path_for_appending (const char *path)
using mode MODE in the calls to open. You cannot use this function to
create files (O_CREAT).
- OPTS specifies the function behaviour in specific cases.
+ OPTS specifies the function behavior in specific cases.
If OPF_TRY_CWD_FIRST, try to open ./STRING before searching PATH.
(ie pretend the first element of PATH is "."). This also indicates
@@ -949,7 +949,7 @@ done:
}
/* This is essentially a convenience, for clients that want the behaviour
of openp, using source_path, but that really don't want the file to be
opened but want instead just to know what the full pathname is (as
qualified against source_path).
@@ -949,7 +949,7 @@ done:
}
-/* This is essentially a convenience, for clients that want the behaviour
+/* This is essentially a convenience, for clients that want the behavior
of openp, using source_path, but that really don't want the file to be
opened but want instead just to know what the full pathname is (as